Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(411)

Unified Diff: media/filters/chunk_demuxer.h

Issue 1637213002: Revert of MSE: Relax the 'media segment must begin with keyframe' requirement (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/filters/chunk_demuxer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/filters/chunk_demuxer.h
diff --git a/media/filters/chunk_demuxer.h b/media/filters/chunk_demuxer.h
index 2425412802433b131346c26518dd63ac0c62d4ef..6954793aa8a5ebcd204cba3ae9248a5a93d7101f 100644
--- a/media/filters/chunk_demuxer.h
+++ b/media/filters/chunk_demuxer.h
@@ -80,8 +80,8 @@
size_t GetBufferedSize() const;
// Signal to the stream that buffers handed in through subsequent calls to
- // Append() belong to a coded frame group that starts at |start_timestamp|.
- void OnStartOfCodedFrameGroup(DecodeTimestamp start_timestamp);
+ // Append() belong to a media segment that starts at |start_timestamp|.
+ void OnNewMediaSegment(DecodeTimestamp start_timestamp);
// Called when midstream config updates occur.
// Returns true if the new config is accepted.
« no previous file with comments | « no previous file | media/filters/chunk_demuxer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698